unit GrayableControls;

{
TGrayableEdit, TGrayableTreeView, TGrayableListView & TGrayableListBox components
Copyright (C) 1996-1997 Jani Jrvinen.

These components are simple modifications of the corresponding base components. Whenever
the Enabled property becomes False, the components set their Color property to clBtnFace.

You may use these component(s) freely in your own projects, but distributing or selling
programs which use these component(s) is prohibited.

Original URL: http://www.dystopia.fi/~janij/files/grayctrl.zip
Date: 8th August, 1997
Contacting the author: janij@dystopia.fi, http://www.dystopia.fi/~janij/
}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls;

type
  TGrayableEdit = class(TEdit)
  private
    { Private declarations }
  protected
    { Protected declarations }
    FPreviousColor : TColor;
    Procedure CMEnabledChanged(Var Message : TMessage); Message cm_EnabledChanged;
  public
    { Public declarations }
    Constructor Create(AOwner : TComponent); Override;
  published
    { Published declarations }
  end;

  TGrayableTreeView = class(TTreeView)
  private
    { Private declarations }
  protected
    { Protected declarations }
    FPreviousColor : TColor;
    Procedure CMEnabledChanged(Var Message : TMessage); Message cm_EnabledChanged;
  public
    { Public declarations }
    Constructor Create(AOwner : TComponent); Override;
  published
    { Published declarations }
  end;

  TGrayableListView = class(TListView)
  private
    { Private declarations }
  protected
    { Protected declarations }
    FPreviousColor : TColor;
    Procedure CMEnabledChanged(Var Message : TMessage); Message cm_EnabledChanged;
  public
    { Public declarations }
    Constructor Create(AOwner : TComponent); Override;
  published
    Property Enabled;
    { Published declarations }
  end;

  TGrayableListBox = class(TListBox)
  private
    { Private declarations }
  protected
    { Protected declarations }
    FPreviousColor : TColor;
    Procedure CMEnabledChanged(Var Message : TMessage); Message cm_EnabledChanged;
  public
    { Public declarations }
    Constructor Create(AOwner : TComponent); Override;
  published
    { Published declarations }
  end;

procedure Register;

implementation

{***********************************************************************}
Constructor TGrayableEdit.Create(AOwner : TComponent);
Begin
  Inherited Create(AOwner);
  FPreviousColor := Color;
  If (FPreviousColor = clBtnFace) Then FPreviousColor := clWhite;
End;

Procedure TGrayableEdit.CMEnabledChanged(Var Message : TMessage);
Begin
  If Enabled Then Color := FPreviousColor
  Else Begin
    FPreviousColor := Color;
    Color := clBtnFace;
  End;
  Inherited;
End;
{***********************************************************************}
Constructor TGrayableTreeView.Create(AOwner : TComponent);
Begin
  Inherited Create(AOwner);
  FPreviousColor := Color;
  If (FPreviousColor = clBtnFace) Then FPreviousColor := clWhite;
End;

Procedure TGrayableTreeView.CMEnabledChanged(Var Message : TMessage);
Begin
  If Enabled Then Color := FPreviousColor
  Else Begin
    FPreviousColor := Color;
    Color := clBtnFace;
  End;
  Inherited;
End;
{***********************************************************************}
Constructor TGrayableListView.Create(AOwner : TComponent);
Begin
  Inherited Create(AOwner);
  FPreviousColor := Color;
  If (FPreviousColor = clBtnFace) Then FPreviousColor := clWhite;
End;

Procedure TGrayableListView.CMEnabledChanged(Var Message : TMessage);
Begin
  If Enabled Then Color := FPreviousColor
  Else Begin
    FPreviousColor := Color;
    Color := clBtnFace;
  End;
  Inherited;
End;
{***********************************************************************}
Constructor TGrayableListBox.Create(AOwner : TComponent);
Begin
  Inherited Create(AOwner);
  FPreviousColor := Color;
  If (FPreviousColor = clBtnFace) Then FPreviousColor := clWhite;
End;

Procedure TGrayableListBox.CMEnabledChanged(Var Message : TMessage);
Begin
  If Enabled Then Color := FPreviousColor
  Else Begin
    FPreviousColor := Color;
    Color := clBtnFace;
  End;
  Inherited;
End;
{***********************************************************************}
procedure Register;
begin
  RegisterComponents('Samples', [TGrayableEdit]);
  RegisterComponents('Samples', [TGrayableTreeView]);
  RegisterComponents('Samples', [TGrayableListView]);
  RegisterComponents('Samples', [TGrayableListBox]);
end;

end.
